@@ -224,7 +224,7 @@ class WafwebaclToCloudFrontProps:
         :summary: The properties for the WafwebaclToCloudFront class.
         '''
         if isinstance(webacl_props, dict):
-            webacl_props = CfnWebACLProps(**webacl_props)
+            webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
         if __debug__:
             type_hints = typing.get_type_hints(WafwebaclToCloudFrontProps.__init__)
             check_type(argname="argument existing_cloud_front_web_distribution", value=existing_cloud_front_web_distribution, expected_type=type_hints["existing_cloud_front_web_distribution"])
